@@ -1,6 +1,6 @@
 # This file is part of nvitop, the interactive NVIDIA-GPU process viewer.
 #
-# Copyright 2021-2023 Xuehai Pan. All Rights Reserved.
+# Copyright 2021-2024 Xuehai Pan. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ import os
 import threading
 import time
 from collections import OrderedDict, defaultdict
-from typing import Callable, ClassVar, Generator, Iterable, NamedTuple, TypeVar
+from typing import TYPE_CHECKING, ClassVar, NamedTuple, TypeVar
 from weakref import WeakSet
 
 from nvitop.api import host
@@ -34,6 +34,10 @@ from nvitop.api.process import GpuProcess, HostProcess
 from nvitop.api.utils import GiB, MiB, Snapshot
 
 
+if TYPE_CHECKING:
+    from collections.abc import Callable, Generator, Iterable
+
+
 __all__ = ['take_snapshots', 'collect_in_background', 'ResourceMetricCollector']
 
 
@@ -296,7 +300,7 @@ class ResourceMetricCollector:  # pylint: disable=too-many-instance-attributes
 
         collector.activate(tag='<tag>')  # alias: start
         collector.deactivate()           # alias: stop
-        collector.reset(tag='<tag>')
+        collector.clear(tag='<tag>')
         collector.collect()
 
         with collector(tag='<tag>'):
@@ -515,7 +519,7 @@ class ResourceMetricCollector:  # pylint: disable=too-many-instance-attributes
     stop = deactivate
 
     @contextlib.contextmanager
-    def context(self, tag: str) -> Generator[ResourceMetricCollector, None, None]:
+    def context(self, tag: str) -> Generator[ResourceMetricCollector]:
         """A context manager for starting and stopping resource metric collection.
 
         Args:
@@ -539,14 +543,14 @@ class ResourceMetricCollector:  # pylint: disable=too-many-instance-attributes
     __call__ = context  # alias for `with collector(tag='<tag>')`
 
     def clear(self, tag: str | None = None) -> None:
-        """Reset the metric collection with the given tag.
+        """Clear the metric collection with the given tag.
 
-        If the tag is not specified, reset the current active collection. For nested collections,
-        the sub-collections will be reset as well.
+        If the tag is not specified, clear the current active collection. For nested collections,
+        the sub-collections will be cleared as well.
 
         Args:
             tag (Optional[str]):
-                The tag to reset. If :data:`None`, the current active collection will be reset.
+                The tag to clear. If :data:`None`, the current active collection will be reset.
 
         Examples:
             >>> collector = ResourceMetricCollector()
@@ -558,12 +562,12 @@ class ResourceMetricCollector:  # pylint: disable=too-many-instance-attributes
             ...     time.sleep(5.0)
             ...     collector.collect()               # metrics within the cumulative 10.0s interval
             ...
-            ...     collector.reset()                 # reset the active collection
+            ...     collector.clear()                 # clear the active collection
             ...     time.sleep(5.0)
             ...     collector.collect()               # metrics within the 5.0s interval
             ...
             ...     with collector(tag='batch'):      # key prefix -> 'train/batch'
-            ...         collector.reset(tag='train')  # reset both 'train' and 'train/batch'
+            ...         collector.clear(tag='train')  # clear both 'train' and 'train/batch'
         """
         with self._lock:
             if self._metric_buffer is None:
@@ -585,6 +589,8 @@ class ResourceMetricCollector:  # pylint: disable=too-many-instance-attributes
                     break
                 buffer = buffer.prev  # type: ignore[assignment]
 
+    reset = clear
+
     def collect(self) -> dict[str, float]:
         """Get the average resource consumption during collection."""
         with self._lock:
