@@ -1,6 +1,6 @@
 # This file is part of nvitop, the interactive NVIDIA-GPU process viewer.
 #
-# Copyright 2021-2023 Xuehai Pan. All Rights Reserved.
+# Copyright 2021-2024 Xuehai Pan. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -28,11 +28,11 @@ import sys as _sys
 import threading as _threading
 from typing import TYPE_CHECKING as _TYPE_CHECKING
 from typing import Any as _Any
-from typing import Callable as _Callable
 from typing import ClassVar as _ClassVar
 
 
 if _TYPE_CHECKING:
+    from collections.abc import Callable as _Callable
     from typing_extensions import Self as _Self  # Python 3.11+
 
 
@@ -307,10 +307,9 @@ class cudaError(Exception):
                 )
             if self.value not in cudaError._errcode_to_name:
                 cudaError._errcode_to_name[self.value] = cudaGetErrorName(self.value)
-            return '{} Code: {} ({}).'.format(
-                cudaError._errcode_to_string[self.value],
-                cudaError._errcode_to_name[self.value],
-                self.value,
+            return (
+                f'{cudaError._errcode_to_string[self.value]} '
+                f'Code: {cudaError._errcode_to_name[self.value]} ({self.value}).'
             )
         except cudaError:
             return f'CUDA Error with code {self.value}.'
@@ -367,10 +366,9 @@ def _extract_cuda_errors_as_classes() -> None:
         new_error_class = type(class_name, (cudaError,), {'__new__': gen_new(err_val)})
         new_error_class.__module__ = __name__
         if err_val in cudaError._errcode_to_string:
-            new_error_class.__doc__ = 'cudaError: {} Code: :data:`{}` ({}).'.format(
-                cudaError._errcode_to_string[err_val],
-                err_name,
-                err_val,
+            new_error_class.__doc__ = (
+                f'cudaError: {cudaError._errcode_to_string[err_val]} '
+                f'Code: :data:`{err_name}` ({err_val}).'
             )
         else:
             new_error_class.__doc__ = f'CUDA Error with code :data:`{err_name}` ({err_val})'
@@ -460,6 +458,8 @@ def __LoadCudaLibrary() -> None:  # pylint: disable=too-many-branches
                     lib_filenames = ['libcudart.so']
                 elif system == 'Windows':
                     lib_filenames = [f'cudart{bits}.dll', 'cudart.dll']
+                else:
+                    lib_filenames = []
 
                 # Open library
                 for lib_filename in lib_filenames:
