@@ -1,6 +1,6 @@
 # This file is part of nvitop, the interactive NVIDIA-GPU process viewer.
 #
-# Copyright 2021-2023 Xuehai Pan. All Rights Reserved.
+# Copyright 2021-2024 Xuehai Pan. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -33,7 +33,6 @@ from types import FunctionType as _FunctionType
 from types import ModuleType as _ModuleType
 from typing import TYPE_CHECKING as _TYPE_CHECKING
 from typing import Any as _Any
-from typing import Callable as _Callable
 from typing import ClassVar as _ClassVar
 
 # Python Bindings for the NVIDIA Management Library (NVML)
@@ -47,6 +46,7 @@ from nvitop.api.utils import colored as __colored
 
 
 if _TYPE_CHECKING:
+    from collections.abc import Callable as _Callable
     from typing_extensions import Self as _Self  # Python 3.11+
     from typing_extensions import TypeAlias as _TypeAlias  # Python 3.10+
 
@@ -66,7 +66,7 @@ __all__ = [  # will be updated in below
 
 
 if not callable(getattr(_pynvml, 'nvmlInitWithFlags', None)):
-    raise ImportError(
+    raise ImportError(  # noqa: TRY004
         'Your installed package `nvidia-ml-py` is corrupted. Please reinstall package '
         '`nvidia-ml-py` via `pip3 install --force-reinstall nvidia-ml-py nvitop`.',
     )
@@ -430,8 +430,11 @@ def nvmlQuery(
             except AttributeError as e1:
                 raise NVMLError_FunctionNotFound from e1
 
-        retval = func(*args, **kwargs)  # type: ignore[operator]
-    except NVMLError_FunctionNotFound as e2:
+        try:
+            retval = func(*args, **kwargs)  # type: ignore[operator]
+        except UnicodeDecodeError as e2:
+            raise NVMLError_Unknown from e2
+    except NVMLError_FunctionNotFound as e3:
         if not ignore_function_not_found:
             identifier = (
                 func
@@ -443,8 +446,8 @@ def nvmlQuery(
                     identifier not in UNKNOWN_FUNCTIONS
                     and len(UNKNOWN_FUNCTIONS) < UNKNOWN_FUNCTIONS_CACHE_SIZE
                 ):
-                    UNKNOWN_FUNCTIONS[identifier] = (func, e2)
-                    LOGGER.error(
+                    UNKNOWN_FUNCTIONS[identifier] = (func, e3)
+                    LOGGER.exception(
                         (
                             'ERROR: A FunctionNotFound error occurred while calling %s.\n'
                             'Please verify whether the `nvidia-ml-py` package is '
@@ -461,7 +464,7 @@ def nvmlQuery(
         raise
 
     if isinstance(retval, bytes):
-        retval = retval.decode('utf-8')
+        retval = retval.decode('utf-8', errors='replace')
     return retval
 
 
@@ -510,10 +513,7 @@ def nvmlQueryFieldValues(
     return values_with_timestamps
 
 
-def nvmlCheckReturn(
-    retval: _Any,
-    types: type | tuple[type, ...] | None = None,
-) -> bool:
+def nvmlCheckReturn(retval: _Any, types: type | tuple[type, ...] | None = None) -> bool:
     """Check whether the return value is not :const:`nvitop.NA` and is one of the given types."""
     if types is None:
         return retval != NA
@@ -592,12 +592,12 @@ if not _pynvml_installation_corrupted:
 
         if __get_running_processes_version_suffix is None:
             # pylint: disable-next=protected-access,no-member
-            _nvmlGetFunctionPointer = _pynvml._nvmlGetFunctionPointer
+            nvmlGetFunctionPointer = _pynvml._nvmlGetFunctionPointer
             __get_running_processes_version_suffix = '_v3'
 
             def lookup(symbol: str) -> _Any | None:
                 try:
-                    ptr = _nvmlGetFunctionPointer(symbol)
+                    ptr = nvmlGetFunctionPointer(symbol)
                 except NVMLError_FunctionNotFound:
                     LOGGER.debug('Failed to found symbol `%s`.', symbol)
                     return None
@@ -708,10 +708,7 @@ if not _pynvml_installation_corrupted:
             NVMLError_Unknown:
                 On any unexpected error.
         """
-        return __nvml_device_get_running_processes(
-            'nvmlDeviceGetComputeRunningProcesses',
-            handle,
-        )
+        return __nvml_device_get_running_processes('nvmlDeviceGetComputeRunningProcesses', handle)
 
     def nvmlDeviceGetGraphicsRunningProcesses(  # pylint: disable=function-redefined
         handle: c_nvmlDevice_t,
@@ -735,10 +732,7 @@ if not _pynvml_installation_corrupted:
             NVMLError_Unknown:
                 On any unexpected error.
         """
-        return __nvml_device_get_running_processes(
-            'nvmlDeviceGetGraphicsRunningProcesses',
-            handle,
-        )
+        return __nvml_device_get_running_processes('nvmlDeviceGetGraphicsRunningProcesses', handle)
 
     def nvmlDeviceGetMPSComputeRunningProcesses(  # pylint: disable=function-redefined
         handle: c_nvmlDevice_t,
@@ -816,10 +810,10 @@ if not _pynvml_installation_corrupted:
 
         if __get_memory_info_version_suffix is None:
             # pylint: disable-next=protected-access,no-member
-            _nvmlGetFunctionPointer = _pynvml._nvmlGetFunctionPointer
+            nvml_get_function_pointer = _pynvml._nvmlGetFunctionPointer
             __get_memory_info_version_suffix = '_v2'
             try:
-                _nvmlGetFunctionPointer('nvmlDeviceGetMemoryInfo_v2')
+                nvml_get_function_pointer('nvmlDeviceGetMemoryInfo_v2')
             except NVMLError_FunctionNotFound:
                 LOGGER.debug('Failed to found symbol `nvmlDeviceGetMemoryInfo_v2`.')
                 c_nvmlMemory_t = c_nvmlMemory_v1_t
