@@ -3,11 +3,13 @@
 
 # pylint: disable=missing-module-docstring,missing-class-docstring,missing-function-docstring
 
+from __future__ import annotations
+
 import itertools
 import threading
 import time
 from operator import attrgetter, xor
-from typing import Any, Callable, NamedTuple
+from typing import TYPE_CHECKING, Any, NamedTuple
 
 from cachetools.func import ttl_cache
 
@@ -29,6 +31,10 @@ from nvitop.gui.library import (
 )
 
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
+
 class Order(NamedTuple):
     key: Callable[[Any], Any]
     reverse: bool
@@ -123,7 +129,8 @@ class ProcessPanel(Displayable):  # pylint: disable=too-many-instance-attributes
         ),
     }
 
-    def __init__(self, devices, compact, filters, win, root):  # pylint: disable=too-many-arguments
+    # pylint: disable-next=too-many-arguments
+    def __init__(self, devices, compact, filters, *, win, root):
         super().__init__(win, root)
 
         self.devices = devices
@@ -175,8 +182,9 @@ class ProcessPanel(Displayable):  # pylint: disable=too-many-instance-attributes
             self.need_redraw = True
             self._compact = value
             processes = self.snapshots
-            n_processes, n_devices = len(processes), len(
-                {p.device.physical_index for p in processes},
+            n_processes, n_devices = (
+                len(processes),
+                len({p.device.physical_index for p in processes}),
             )
             self.full_height = 1 + max(6, 5 + n_processes + n_devices - 1)
             self.compact_height = 1 + max(6, 5 + n_processes)
@@ -231,7 +239,7 @@ class ProcessPanel(Displayable):  # pylint: disable=too-many-instance-attributes
             self.height = height
             self.host_offset = max(-1, min(self.host_offset, info_length - self.width + 39))
 
-        if old_host_offset not in (self.host_offset, LARGE_INTEGER):
+        if old_host_offset not in {self.host_offset, LARGE_INTEGER}:
             self.beep()
 
         if self.selection.is_set():
@@ -398,7 +406,7 @@ class ProcessPanel(Displayable):  # pylint: disable=too-many-instance-attributes
         column_width = len(column)
         reverse = xor(reverse, self.reverse)
         indicator = '▼' if reverse else '▲'
-        if self.order in ('cpu_percent', 'memory_percent', 'time'):
+        if self.order in {'cpu_percent', 'memory_percent', 'time'}:
             offset -= host_offset
             if self.order == 'time':
                 offset += len(self.host_headers[-2]) - 4
