@@ -1,6 +1,6 @@
 # This file is part of nvitop, the interactive NVIDIA-GPU process viewer.
 #
-# Copyright 2021-2023 Xuehai Pan. All Rights Reserved.
+# Copyright 2021-2024 Xuehai Pan. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -57,30 +57,24 @@ Python API:
 from __future__ import annotations
 
 import argparse
-import getpass
+import contextlib
 import math
 import os
 import sys
 import warnings
-from typing import TYPE_CHECKING, Any, Callable, Iterable, Sequence, overload
+from typing import TYPE_CHECKING, overload
 
-from nvitop.api import Device, GpuProcess, Snapshot, colored, human2bytes, libnvml
+from nvitop.api import Device, GpuProcess, Snapshot, colored, host, human2bytes, libnvml
 from nvitop.version import __version__
 
 
 if TYPE_CHECKING:
+    from collections.abc import Callable, Iterable, Sequence
     from typing_extensions import Literal  # Python 3.8+
 
 
 __all__ = ['select_devices']
 
-try:
-    USERNAME = getpass.getuser()
-except ModuleNotFoundError:
-    USERNAME = os.getlogin()
-
-TTY = sys.stdout.isatty()
-
 
 @overload
 def select_devices(  # pylint: disable=too-many-arguments
@@ -97,9 +91,7 @@ def select_devices(  # pylint: disable=too-many-arguments
     tolerance: int,
     free_accounts: list[str] | None,
     sort: bool,
-    **kwargs: Any,
-) -> list[int] | list[tuple[int, int]]:
-    ...
+) -> list[int] | list[tuple[int, int]]: ...
 
 
 @overload
@@ -117,9 +109,7 @@ def select_devices(  # pylint: disable=too-many-arguments
     tolerance: int,
     free_accounts: list[str] | None,
     sort: bool,
-    **kwargs: Any,
-) -> list[int] | list[tuple[int, int]]:
-    ...
+) -> list[int] | list[tuple[int, int]]: ...
 
 
 @overload
@@ -137,12 +127,11 @@ def select_devices(  # pylint: disable=too-many-arguments
     tolerance: int,
     free_accounts: list[str] | None,
     sort: bool,
-    **kwargs: Any,
-) -> list[Device]:
-    ...
+) -> list[Device]: ...
 
 
-def select_devices(  # pylint: disable=too-many-branches,too-many-statements,too-many-locals,unused-argument,too-many-arguments
+# pylint: disable-next=too-many-branches,too-many-statements,too-many-locals,too-many-arguments
+def select_devices(
     devices: Iterable[Device] | None = None,
     *,
     format: Literal['index', 'uuid', 'device'] = 'index',  # pylint: disable=redefined-builtin
@@ -156,7 +145,6 @@ def select_devices(  # pylint: disable=too-many-branches,too-many-statements,too
     tolerance: int = 0,  # in percentage
     free_accounts: list[str] | None = None,
     sort: bool = True,
-    **kwargs: Any,
 ) -> list[int] | list[tuple[int, int]] | list[str] | list[Device]:
     """Select a subset of devices satisfying the specified criteria.
 
@@ -209,7 +197,7 @@ def select_devices(  # pylint: disable=too-many-branches,too-many-statements,too
     Returns:
         A list of the device identifiers.
     """
-    assert format in ('index', 'uuid', 'device')
+    assert format in {'index', 'uuid', 'device'}
     assert tolerance >= 0
     tolerance = tolerance / 100.0
 
@@ -537,7 +525,8 @@ def parse_arguments() -> argparse.Namespace:
         args.sep = '\0'
 
     if args.free_accounts is not None and len(args.free_accounts) == 0:
-        args.free_accounts.append(USERNAME)
+        with contextlib.suppress(ImportError, OSError):
+            args.free_accounts.append(host.getuser())
 
     return args
 
@@ -573,11 +562,23 @@ def main() -> int:
         )
         return 3
 
-    identifiers = select_devices(devices, **vars(args))
+    identifiers = select_devices(  # type: ignore[call-overload]
+        devices,
+        format=args.format,
+        min_count=args.min_count,
+        max_count=args.max_count,
+        min_free_memory=args.min_free_memory,
+        min_total_memory=args.min_total_memory,
+        max_gpu_utilization=args.max_gpu_utilization,
+        max_memory_utilization=args.max_memory_utilization,
+        tolerance=args.tolerance,
+        free_accounts=args.free_accounts,
+        sort=args.sort,
+    )
     identifiers = list(map(str, identifiers))
     result = args.sep.join(identifiers)
 
-    if not TTY:
+    if not sys.stdout.isatty():
         print('CUDA_VISIBLE_DEVICES="{}"'.format(','.join(identifiers)), file=sys.stderr)
 
     retval = 0
