@@ -1,6 +1,6 @@
 # This file is part of nvitop, the interactive NVIDIA-GPU process viewer.
 #
-# Copyright 2021-2023 Xuehai Pan. All Rights Reserved.
+# Copyright 2021-2024 Xuehai Pan. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,9 @@
 # ==============================================================================
 """An interactive NVIDIA-GPU process viewer and beyond, the one-stop solution for GPU process management."""
 
-__version__ = '1.3.2'
+# pylint: disable=invalid-name
+
+__version__ = '1.4.1'
 __license__ = 'GPL-3.0-only AND Apache-2.0'
 __author__ = __maintainer__ = 'Xuehai Pan'
 __email__ = 'XuehaiPan@pku.edu.cn'
@@ -28,8 +30,8 @@ if not __release__:
 
     try:
         prefix, sep, suffix = (
-            subprocess.check_output(
-                ['git', 'describe', '--abbrev=7'],  # noqa: S603,S607
+            subprocess.check_output(  # noqa: S603
+                ['git', 'describe', '--abbrev=7'],  # noqa: S607
                 cwd=os.path.dirname(os.path.abspath(__file__)),
                 stderr=subprocess.DEVNULL,
                 text=True,
@@ -43,7 +45,7 @@ if not __release__:
         if sep:
             version_prefix, dot, version_tail = prefix.rpartition('.')
             prefix = f'{version_prefix}{dot}{int(version_tail) + 1}'
-            __version__ = sep.join((prefix, suffix))
+            __version__ = f'{prefix}{sep}{suffix}'
             del version_prefix, dot, version_tail
         else:
             __version__ = prefix
@@ -69,9 +71,15 @@ PYNVML_VERSION_CANDIDATES = (
     '11.525.84',
     '11.525.112',
     '11.525.131',
+    '11.525.150',
     '12.535.77',
     '12.535.108',
     '12.535.133',
+    '12.535.161',
+    '12.550.52',
+    '12.550.89',
+    '12.555.43',
+    '12.560.30',
 )
 """The list of supported ``nvidia-ml-py`` versions.
 See also: `nvidia-ml-py's Release History <https://pypi.org/project/nvidia-ml-py/#history>`_.
